﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Syncfusion.Windows.Tools.Controls;
using Syncfusion.Windows.Shared;
using System.Diagnostics;

namespace RichTextBoxAdvSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : RibbonWindow
    {
        public MainWindow()
        {
            InitializeComponent();

            rte.FileOpening += (sender, e) =>
                {
                    rte.Document = DocxImporting.ConvertToDocumentAdv(e.DocumentStream, e.FormatType);
                    PageCount = rte.Viewer.Pages.Count;
                };

            rte.FileSaving += (sender, e) =>
                {
                    DocxExporting.ConvertToDocument(rte.Document, e.DoucmentStream, e.FormatType);
                };

            rte.Loaded += (sender, e) =>
                {
                    PageCount = rte.Viewer.Pages.Count;
                };
            DataContext = rte;
            pagecount.DataContext = this;
            SkinStorage.SetVisualStyle(this, "Metro");
            InitCustomRibbonHelper();
        }
        private void InitCustomRibbonHelper()
        {
            ribbon.Loaded += new RoutedEventHandler(OnLoaded);
            ribbon.BackStageButton.Visibility = Visibility.Hidden;
            AddFontFamily();
            if (FontFamilyCombo != null)
            {
                FontFamilyCombo.DropDownClosed += (sender, e) =>
                {
                    if (rte != null)
                    {
                        RichTextBoxAdv.ChangeFontFamily.Execute(FontFamilyCombo.SelectedItem, null);
                    }
                };
            }
            if (FontSizeCombo != null)
            {
                FontSizeCombo.DropDownClosed += (sender, e) =>
                {
                    if (rte != null)
                    {
                        RichTextBoxAdv.ChangeFontSize.Execute(FontSizeCombo.SelectedItem, null);
                    }
                };
            }
            if (FontColorPicker != null)
            {
                FontColorPicker.ColorChanged += (sender, args) =>
                {
                    if (rte != null)
                    {
                        rte.Selection.ChangeForeground(FontColorPicker.Color);
                        SplitButton splitbutton = (SplitButton)FontColorPicker.Parent;
                        splitbutton.IsDropDownOpen = false;
                    }
                };
            }
            if (PrintDocument != null)
            {
                PrintDocument.Click += (sender, e) =>
                {
                    ribbon.BackStageButton.IsOpen = false;
                };
            }

            if (OpenButton != null)
            {
                OpenButton.Click += (sender, e) =>
                {
                    ribbon.BackStageButton.IsOpen = false;
                };
            }
            if (NewDocumentButton != null)
            {
                NewDocumentButton.Click += (sender, e) =>
                {
                    if (ribbon != null)
                    {
                        ribbon.BackStageButton.IsOpen = false;
                        rte.DocumentTitle = "Untitled";
                    }
                };
            }

            if (CreateDocumentButton != null)
            {
                CreateDocumentButton.Click += (sender, e) =>
                {
                    if (ribbon != null)
                    {
                        ribbon.BackStageButton.IsOpen = false;
                        rte.DocumentTitle = "Untitled";
                    }
                };
            }

            if (FontColorSplitButton != null)
                FontColorSplitButton.Click += (sender, e) =>
                {
                    if (FontColorPicker != null && rte != null)
                    {
                        rte.Selection.ChangeForeground(FontColorPicker.Color);
                    }
                };
            if (ribbon != null)
            {
                ribbon.BackStageClosed += (sender, e) =>
                {
                    rte.Focus();
                };
            }
        }
        public FontFamilies FontFamilySource
        {
            get { return (FontFamilies)GetValue(FontFamilySourceProperty); }
            set { SetValue(FontFamilySourceProperty, value); }
        }

        // Using a DependencyProperty as the backing store for FontFamilySource.
        public static readonly DependencyProperty FontFamilySourceProperty =
            DependencyProperty.Register("FontFamilySource", typeof(FontFamilies), typeof(MainWindow), new PropertyMetadata(new FontFamilies()));
        public static readonly DependencyProperty FontSizeSourceProperty = DependencyProperty.Register("FontSizeSource", typeof(double[]), typeof(MainWindow),
            new PropertyMetadata(new double[] { 8, 9, 10, 11, 12, 14, 16, 18, 20, 24, 26, 28, 36, 48, 72 }));

        public double[] FontSizeSource
        {
            get
            {
                return (double[])GetValue(FontSizeSourceProperty);
            }
            set
            {
                SetValue(FontSizeSourceProperty, value);
            }
        }
        public int PageCount
        {
            get { return (int)GetValue(PageCountProperty); }
            set { SetValue(PageCountProperty, value); }
        }

        // Using a DependencyProperty as the backing store for PageCount.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty PageCountProperty =
            DependencyProperty.Register("PageCount", typeof(int), typeof(MainWindow), new PropertyMetadata(0));


        private void OnLoaded(object sender, RoutedEventArgs e)
        {
            Window window = this as Window;
            if (window != null)
            {
                window.CommandBindings.Add(new CommandBinding(RichTextBoxAdv.Save, SaveExecute));
                window.CommandBindings.Add(new CommandBinding(RichTextBoxAdv.SaveAs, SaveAsExecute));
                window.CommandBindings.Add(new CommandBinding(RichTextBoxAdv.Print, PrintExecute));
                window.CommandBindings.Add(new CommandBinding(RichTextBoxAdv.Open, OpenExecute));
                window.CommandBindings.Add(new CommandBinding(RichTextBoxAdv.New, NewExecute));
            }
            if (rte != null)
                rte.Focus();
        }
        private void SaveExecute(object sender, ExecutedRoutedEventArgs e)
        {
            if (rte != null)
            {
                rte.SaveDocument(string.Empty);
                rte.Focus();
            }
        }

        private void SaveAsExecute(object sender, ExecutedRoutedEventArgs e)
        {
            string extension = string.Empty;
            if (e.Parameter == null)
                extension = ".docx";
            else
                extension = e.Parameter.ToString();
            if (rte != null)
            {
                rte.SaveDocument(extension);
            }
        }

        private void PrintExecute(object sender, ExecutedRoutedEventArgs e)
        {
            if (rte != null)
            {
                rte.PrintDocument();
                rte.Focus();
            }
        }

        private void NewExecute(object sender, ExecutedRoutedEventArgs e)
        {
            if (rte != null)
            {
                rte.CreateEmptyDocument();
                rte.Focus();
            }
        }

        private void OpenExecute(object sender, ExecutedRoutedEventArgs e)
        {
            if (rte != null)
            {
                rte.OpenDocument();
                rte.Focus();
            }
        }

        private void AddFontFamily()
        {
            FontFamilySource = new FontFamilies();
            foreach (FontFamily fontfamily in Fonts.SystemFontFamilies)
            {
                FontFamilySource.Add(fontfamily);
            }
        }

    }
    public class FontFamilies : List<FontFamily>
    {
        public FontFamilies()
        {
            foreach (FontFamily fontfamily in Fonts.SystemFontFamilies)
            {
                Add(fontfamily);
            }
        }
    }
    public class ZoomFactorInPercentage : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            double factor = Math.Round(System.Convert.ToDouble(value), 2);
            if (factor == 0)
            {
                factor = 0.1;
            }
            return (int)(factor * 100 * 4);
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class RunAdv : Run
    {
        public RunAdv()
        {

        }

        public string RunText
        {
            get { return (string)GetValue(RunTextProperty); }
            set { SetValue(RunTextProperty, value); }
        }

        // Using a DependencyProperty as the backing store for RunText.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty RunTextProperty =
            DependencyProperty.Register("RunText", typeof(string), typeof(RunAdv), new PropertyMetadata(string.Empty, new PropertyChangedCallback(OnRunTextChanged)));

        private static void OnRunTextChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            RunAdv runadv = d as RunAdv;
            runadv.OnRunTextChanged(e);
        }

        private void OnRunTextChanged(DependencyPropertyChangedEventArgs e)
        {
            base.Text = (string)e.NewValue;
        }
    }
}
